@@ -546,7 +546,7 @@ class DISA:
         """
         omega = max(self.patterns[i]["X"] + self.patterns[i]["Y"] - 1, 1/self.size_of_dataset)/(self.patterns[i]["X"] * self.patterns[i]["Y"])
         v = 1 / max(self.patterns[i]["X"], self.patterns[i]["Y"])
-        return (self.lift(i)-omega)/(v-omega)
+        return (self.lift(i)-omega)/(v-omega) if (v-omega) != 0 else 0
 
     def collective_strength(self, i):
         """ Calculates the collective strength metric of a given subspace
@@ -560,7 +560,7 @@ class DISA:
         metric : float
             Collective strength of subspace
         """
-        return (self.patterns[i]["XY"] + self.patterns[i]["_X_Y"] / self.patterns[i]["_X"]) / (self.patterns[i]["X"] * self.patterns[i]["Y"] + self.patterns[i]["_X"] * self.patterns[i]["_Y"])
+        return (self.patterns[i]["XY"] + self.patterns[i]["_X_Y"] / self.patterns[i]["_X"]) / (self.patterns[i]["X"] * self.patterns[i]["Y"] + self.patterns[i]["_X"] * self.patterns[i]["_Y"]) if (self.patterns[i]["X"] * self.patterns[i]["Y"] + self.patterns[i]["_X"] * self.patterns[i]["_Y"]) != 0 else 0
 
     def cosine(self, i):
         """ Calculates cosine metric of a given subspace
@@ -574,7 +574,7 @@ class DISA:
         metric : float
             Cosine of subspace
         """
-        return self.patterns[i]["XY"] / math.sqrt(self.patterns[i]["X"] * self.patterns[i]["Y"])
+        return self.patterns[i]["XY"] / math.sqrt(self.patterns[i]["X"] * self.patterns[i]["Y"]) if self.patterns[i]["X"] * self.patterns[i]["Y"] != 0 else 0
 
     def interestingness(self, i):
         """ Calculates interestingness metric of a given subspace
